diff -r -u8 flexi-streams-0.13.1.original/test/test.lisp flexi-streams-0.13.1/test/test.lisp
--- flexi-streams-0.13.1.original/test/test.lisp	2007-03-09 03:14:30.000000000 +0200
+++ flexi-streams-0.13.1/test/test.lisp	2007-11-09 01:16:50.656250000 +0200
@@ -223,17 +223,17 @@
 
 (defmacro using-values ((&rest values) &body body)
   "Executes BODY and feeds an element from VALUES to the USE-VALUE
 restart each time a FLEXI-STREAM-ENCODING-ERROR is signaled.  Signals
 an error when there are more or less FLEXI-STREAM-ENCODING-ERRORs than
 there are elements in VALUES."
   (flex::with-unique-names (value-stack condition-counter)
     `(let ((,value-stack ',values)
-	   (,condition-counter 0))
+       (,condition-counter 0))
        (handler-bind ((flexi-stream-encoding-error
                        #'(lambda (c)
                            (declare (ignore c)) 
                            (unless ,value-stack
                              (error "Too many FLEXI-STREAM-ENCODING-ERRORs signaled, expected only ~A."
                                     ,(length values)))
                            (incf ,condition-counter)
                            (use-value (pop ,value-stack)))))
@@ -289,25 +289,40 @@
       (check (string= "aY" (using-values (#\Y)
                              (read-flexi-line `(,(char-code #\a) #x00 #x00 #x00 #x01) :utf-32le))))
       (check (string= "Y" (using-values (#\Y) (read-flexi-line `(#x01) :utf-32be))))
       (check (string= "Y" (using-values (#\Y) (read-flexi-line `(#x01 #x01) :utf-32be))))
       (check (string= "Y" (using-values (#\Y) (read-flexi-line `(#x01 #x01 #x01) :utf-32be))))
       (check (string= "aY" (using-values (#\Y)
                              (read-flexi-line `(#x00 #x00 #x00 ,(char-code #\a) #x01) :utf-32be)))))))
 
+(defun column-tracking-test()
+  (with-test ("Column tracking")
+    (let ((stream (make-flexi-stream (make-in-memory-output-stream) :external-format :utf-8)))
+      (write-char #\A stream)
+      (write-char #\B stream)
+      (write-char #\C stream)
+      (check (eql 3 (flex::stream-line-column stream)))
+      (write-char #\Newline stream)
+      (check (eql 0 (flex::stream-line-column stream)))
+      (write-string "abc" stream)
+      (check (eql 3 (flex::stream-line-column stream)))
+      (write-string (format nil "abc~Cd" #\Newline) stream)
+      (check (eql 1 (flex::stream-line-column stream))))))
+                             
 (defun run-tests ()
   "Applies COMPARE-FILES to all test scenarios created with
 CREATE-TEST-COMBINATIONS, runs test for handling of encoding errors,
 and shows simple statistics at the end."
   (let* ((*test-success-counter* 0)
          (args-list (loop for (file-name symbols) in *test-files*
                           nconc (create-test-combinations file-name symbols)))
          (no-tests (* 4 (length args-list))))
     #+:lispworks
     (setq no-tests (* 2 no-tests))
     (dolist (args args-list)
       (apply #'compare-files args))
-    (incf no-tests)
+    (incf no-tests 2)
     (encoding-error-handling-test)
+    (column-tracking-test)
     (format *error-output* "~%~%~:[~A of ~A tests failed..~;~*All ~A tests passed~].~%"
             (= no-tests *test-success-counter*) (- no-tests *test-success-counter*) no-tests)))
             
